@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 66987 2011-02-21 18:37:54Z CJP $"
-__revision__ = "$Revision: 66987 $"
+__svnid__ = "$Id: Editra.py 67100 2011-03-01 15:12:16Z CJP $"
+__revision__ = "$Revision: 67100 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -440,9 +440,6 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname, line)
 
                 # Make sure the window is brought to the front
-                if wx.Platform == '__WXMSW__' and not window.IsIconized():
-                    # HACK to work around Raise not bring window to front
-                    window.Iconize(True)
                 if window.IsIconized():
                     window.Iconize(False)
                 window.Raise()
