@@ -61,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 66988 2011-02-22 02:21:05Z CJP $"
-__revision__ = "$Revision: 66988 $"
+__svnid__ = "$Id: outbuff.py 67169 2011-03-11 03:42:56Z CJP $"
+__revision__ = "$Revision: 67169 $"
 
 __all__ = ["OutputBuffer", "OutputBufferEvent", "ProcessBufferMixin",
            "ProcessThreadBase", "ProcessThread", "TaskThread", 
@@ -261,7 +261,11 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self.SetReadOnly(False)
         txt = u''.join(self._updates[:])
         start = self.GetLength()
-        self.AppendText(txt)
+        if u'\0' in txt:
+            # HACK: handle displaying NULLs in the STC
+            self.AddStyledText('\0'.join(txt.encode('utf-8'))+'\0')
+        else:
+            self.AppendText(txt)
         self.GotoPos(self.GetLength())
         self._updates = list()
         self.ApplyStyles(start, txt)
