@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 67008 2011-02-24 03:33:36Z CJP $"
-__revision__ = "$Revision: 67008 $"
+__svnid__ = "$Id: ed_basestc.py 67152 2011-03-08 23:40:02Z CJP $"
+__revision__ = "$Revision: 67152 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -38,23 +38,7 @@ from profiler import Profile_Get
 import plugin
 import iface
 import util
-
-from extern.embeddedimage import PyEmbeddedImage
-BreakPoint = PyEmbeddedImage(
-    "iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAAAAXNSR0IArs4c6QAAAAZiS0dE"
-    "AP8A/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9sCGAMVMT9tMisAAAJE"
-    "SURBVCjPZdPRSxRRFMfx7+bsdHVnZy+zY46x0RJbDFIR6YNkxBJB9RbiQ0/hHyAS0WP0F4hI"
-    "f0NEkIRPZSCx1Bo+SEiWDGKxkMUEY1xdt724g/bgMmrdx8P5XA7n/m5ql8d7HDpvXl9hfv4d"
-    "QRAQhhGe5+L7PkND17h5+8PhVlKH8eSERRCsUi6XAcjnXTY2IgAqlQq+f44HD7cTfOxfWJQ2"
-    "RWlTHuznwtnTlAf7k1oQrDI5YSXYAHg5fZGp++NcLZUQhQLhwiJ6YS1pUihEGLK9vs7U7CuK"
-    "008YHvm0j6vVKr6wkGGIWtcECwpXmAmO9A6aCGkofGFRrVYZxt4fe+7pM0oGuJEgq1JY8ZEd"
-    "YsV7dNe7cCNBydjvT8Y2tMKNC3R32OSyEldmMUQmwbFoEKk61IF4C0PXDrArLCSSXNamVzpk"
-    "pI0jcgn+o+ukSQPQ4hiusGC7jYWUpOu79J5yyEtJl8hyQtp0cRyAX7ojuWjzu0JICVEbW4UC"
-    "+nOTPWGSl5Ie4ZBKd5LOdIKO6QGQoNlF15pYhQKstd95ZGycZdEk1g2yIoMpbdL5bpAOSIkp"
-    "HbIiQ0NtsSyajIyNH4RESgfle8yEXwiDr7QarfaQJgiTVqOJqv3gRbiE8j2kdA4W5nkud0fv"
-    "EQQrPHo+y8D7GpdkEV94BDpkSdVYJOT86C3Kfh+e5x7N9sfFOwTBCrXaN6LoN3G8g9Y7CGFi"
-    "GCau61AsnsH3+7g8MPP/xwB4O1cmDH+i1GZSkzKH553k+o3KkfD8BZeW03dkWsHXAAAAAElF"
-    "TkSuQmCC")
+import ed_marker
 
 #-----------------------------------------------------------------------------#
 
@@ -63,9 +47,8 @@ MARK_MARGIN = 0
 NUM_MARGIN  = 1
 FOLD_MARGIN = 2
 
-# Marker IDs
-MARKER_BOOKMARK   = 0
-MARKER_BREAKPOINT = 1
+# Markers (3rd party)
+MARKER_VERT_EDIT = ed_marker.NewMarkerId()
 
 # Key code additions
 ALT_SHIFT = wx.stc.STC_SCMOD_ALT|wx.stc.STC_SCMOD_SHIFT
@@ -94,7 +77,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                           indenter=None,    # Auto indenter
                           lang_id=0)        # Language ID from syntax module
 
-        self.vert_edit = vertedit.VertEdit(self)
+        self.vert_edit = vertedit.VertEdit(self, markerNumber=MARKER_VERT_EDIT)
         self._line_num = True # Show line numbers
         self._last_cwidth = 1 # one pixel
 
@@ -145,29 +128,73 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         if line < 0:
             line = self.GetCurrentLine()
-        return self.MarkerAdd(line, MARKER_BOOKMARK)
+        bmark = ed_marker.Bookmark()
+        bmark.Set(self, line)
+        return bmark.Handle
 
     def RemoveBookmark(self, line):
         """Remove the book mark from the given line
         @param line: int
 
         """
-        self.MarkerDelete(line, MARKER_BOOKMARK)
+        ed_marker.Bookmark().Set(self, line, delete=True)
 
     def RemoveAllBookmarks(self):
         """Remove all the bookmarks in the buffer"""
-        self.MarkerDeleteAll(MARKER_BOOKMARK)
+        ed_marker.Bookmark().DeleteAll(self)
+ 
+    def DeleteAllBreakpoints(self):
+        """Delete all the breakpoints in the buffer"""
+        ed_marker.Breakpoint().DeleteAll(self)
+        ed_marker.BreakpointDisabled().DeleteAll(self)
+        ed_marker.BreakpointStep().DeleteAll(self)
 
     def DeleteBreakpoint(self, line):
         """Delete the breakpoint from the given line"""
-        self.MarkerDelete(line, MARKER_BREAKPOINT)
+        ed_marker.Breakpoint().Set(self, line, delete=True)
+        ed_marker.BreakpointDisabled().Set(self, line, delete=True)
 
-    def SetBreakpoint(self, line):
-        """Set a breakpoint marker on the given line"""
-        self.MarkerAdd(line, MARKER_BREAKPOINT)
+    def _SetBreakpoint(self, mobj, line=-1):
+        """Set the breakpoint state
+        @param mtype: Marker object
+        @return: int (-1 if already set)
+
+        """
+        handle = -1
+        if line < 0:
+            line = self.GetCurrentLine()
+        if not mobj.IsSet(self, line):
+            # Clear other set breakpoint marker states on same line
+            ed_marker.Breakpoint().Set(self, line, delete=True)
+            ed_marker.BreakpointDisabled().Set(self, line, delete=True)
+            mobj.Set(self, line, delete=False)
+            handle = mobj.Handle
+        return handle
+
+    def SetBreakpoint(self, line=-1):
+        """Set a breakpoint marker on the given line
+        @return: breakpoint handle
+
+        """
+        handle = self._SetBreakpoint(ed_marker.Breakpoint(), line)
+        return handle
+
+    def SetBreakpointDisabled(self, line=-1):
+        """Set a disabled breakpoint indicator."""
+        handle = self._SetBreakpoint(ed_marker.BreakpointDisabled(), line)
+        return handle
+
+    def ShowStepMarker(self, line=-1, show=True):
+        """Show the step (arrow) marker to the given line."""
+        if line < 0:
+            line = self.GetCurrentLine()
+        mark = ed_marker.BreakpointStep()
+        if show:
+            mark.Set(self, line, delete=False)
+        else:
+            mark.DeleteAll(self)
 
     def AddLine(self, before=False, indent=False):
-
         """Add a new line to the document
         @keyword before: whether to add the line before current pos or not
         @keyword indent: autoindent the new line
@@ -423,10 +450,8 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: all margin markers are defined
 
         """
+        # Get the colours for the various markers
         style = self.GetItemByName('foldmargin_style')
-        # The foreground/background settings for the marker column seem to
-        # backwards from what the parameters take so use our Fore color for
-        # the stcs back and visa versa for our Back color.
         back = style.GetFore()
         rgb = eclib.HexToRGB(back[1:])
         back = wx.Colour(red=rgb[0], green=rgb[1], blue=rgb[2])
@@ -435,24 +460,26 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         rgb = eclib.HexToRGB(fore[1:])
         fore = wx.Colour(red=rgb[0], green=rgb[1], blue=rgb[2])
 
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPEN,
-                          wx.stc.STC_MARK_BOXMINUS, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDER,
-                          wx.stc.STC_MARK_BOXPLUS,  fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERSUB,
-                          wx.stc.STC_MARK_VLINE, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERTAIL,
-                          wx.stc.STC_MARK_LCORNER, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEREND,
-                          wx.stc.STC_MARK_BOXPLUSCONNECTED, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPENMID,
-                          wx.stc.STC_MARK_BOXMINUSCONNECTED, fore, back)
-        self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDERMIDTAIL,
-                          wx.stc.STC_MARK_TCORNER, fore, back)
-        self.MarkerDefine(MARKER_BOOKMARK, wx.stc.STC_MARK_SHORTARROW, fore, back)
-        self.MarkerDefineBitmap(MARKER_BREAKPOINT, BreakPoint.Bitmap)
-        self.SetFoldMarginHiColour(True, fore)
-        self.SetFoldMarginColour(True, fore)
+        # Buffer background highlight
+        caret_line = self.GetItemByName('caret_line').GetBack()
+        rgb = eclib.HexToRGB(caret_line[1:])
+        clback = wx.Colour(*rgb)
+
+        # Code Folding markers
+        folder = ed_marker.FoldMarker()
+        folder.Foreground = fore
+        folder.Background = back
+        folder.RegisterWithStc(self)
+
+        # Bookmarks
+        ed_marker.Bookmark().RegisterWithStc(self)
+
+        # Breakpoints
+        ed_marker.Breakpoint().RegisterWithStc(self)
+        ed_marker.BreakpointDisabled().RegisterWithStc(self)
+        step = ed_marker.BreakpointStep()
+        step.Background = clback
+        step.RegisterWithStc(self)
 
     def DoZoom(self, mode):
         """Zoom control in or out
@@ -710,6 +737,15 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         pos = max(0, pos-1)
         return 'comment' in self.FindTagById(self.GetStyleAt(pos))
 
+    def HasMarker(self, line, marker):
+        """Check if the given line has the given marker set
+        @param line: line number
+        @param marker: marker id
+
+        """
+        mask = self.MarkerGet(line)
+        return bool(1<<marker & mask)
+
     def HasSelection(self):
         """Check if there is a selection in the buffer
         @return: bool
