@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 67027 2011-02-25 21:04:49Z CJP $"
-__revision__ = "$Revision: 67027 $"
+__svnid__ = "$Id: ed_main.py 67126 2011-03-04 23:44:13Z CJP $"
+__revision__ = "$Revision: 67126 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -663,8 +663,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     def SaveAllBuffers(self):
         """Save all open editor buffers"""
         for page in xrange(self.nb.GetPageCount()):
-            if isinstance(self.nb.GetPage(page), wx.stc.StyledTextCtrl):
-                self.SaveFile(self.nb.GetPageText(page), self.nb.GetPage(page))
+            buff = self.nb.GetPage(page)
+            if isinstance(buff, wx.stc.StyledTextCtrl):
+                if buff.GetModify():
+                    self.SaveFile(self.nb.GetPageText(page), buff)
 
     def OnSave(self, evt):
         """Save Current or All Buffers
