@@ -14,8 +14,8 @@ Shelf plugin and control implementation
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_shelf.py 66747 2011-01-24 21:25:00Z CJP $"
-__revision__ = "$Revision: 66747 $"
+__svnid__ = "$Id: ed_shelf.py 67235 2011-03-18 17:44:07Z CJP $"
+__revision__ = "$Revision: 67235 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -105,7 +105,7 @@ class Shelf(plugin.Plugin):
         view = parent.GetMenuBar().GetMenuByName("view")
         menu = delegate.GetMenu()
         pos = 0
-        for pos in xrange(view.GetMenuItemCount()):
+        for pos in range(view.GetMenuItemCount()):
             mitem = view.FindItemByPosition(pos)
             if mitem.GetId() == ed_glob.ID_PERSPECTIVES:
                 break
@@ -127,9 +127,10 @@ class Shelf(plugin.Plugin):
                hasattr(observer, 'InstallComponents'):
                 observer.InstallComponents(parent)
 
-        delegate.StockShelf(Profile_Get('SHELF_ITEMS', 'list', []))
-        delegate.SetPerspective(Profile_Get('SHELF_LAYOUT', 'str', u""))
-        delegate.SetSelection(Profile_Get('SHELF_SELECTION', 'int', -1))
+        # Only Load Perspective if all items are loaded
+        if delegate.StockShelf(Profile_Get('SHELF_ITEMS', 'list', [])):
+            delegate.SetPerspective(Profile_Get('SHELF_LAYOUT', 'str', u""))
+            delegate.SetSelection(Profile_Get('SHELF_SELECTION', 'int', -1))
         return delegate
 
 #--------------------------------------------------------------------------#
@@ -384,8 +385,11 @@ class EdShelfDelegate(object):
 
         """
         if pdata:
-            self._shelf.LoadPerspective(pdata)
-            self._shelf.Update()
+            try:
+                self._shelf.LoadPerspective(pdata)
+                self._shelf.Update()
+            except Exception, msg:
+                self._log("[shelf][err] Failed LoadPerspective: %s" % msg)
 
     def GetMenu(self):
         """Return the menu of this object
@@ -413,7 +417,10 @@ class EdShelfDelegate(object):
         combo = 0
         for item in menu_items:
             combo += 1
-            item[1].SetText(item[1].GetText() + "\tCtrl+Alt+" + str(combo))
+            shortcut = u""
+            if combo < 10:
+                shortcut = u"\tCtrl+Alt+" + str(combo)
+            item[1].SetText(item[1].GetText() + shortcut)
             menu.AppendItem(item[1])
         return menu
 
@@ -521,7 +528,7 @@ class EdShelfDelegate(object):
         @return: reference to the selected page or None if no instance is
 
         """
-        for page in xrange(self._shelf.GetPageCount()):
+        for page in range(self._shelf.GetPageCount()):
             ctrl = self._shelf.GetPage(page)
             if window == ctrl:
                 self._shelf.SetSelection(page)
@@ -535,19 +542,29 @@ class EdShelfDelegate(object):
 
         """
         if self._shelf and index > 0 and index < self._shelf.GetPageCount():
-            self._shelf.SetSelection(index)
+            try:
+                self._shelf.SetSelection(index)
+            except Exception, msg:
+                self._log("[shelf][err] Failed SetSelection: %s" % msg)
 
     def StockShelf(self, i_list):
         """Fill the shelf by opening an ordered list of items
         @param i_list: List of named L{ShelfI} instances
         @type i_list: list of strings
+        @return: bool (True if all loaded / False otherwise)
 
         """
+        bLoaded = True
         for item in i_list:
             if self.CanStockItem(item):
                 itemid = self.GetItemId(item)
                 if itemid:
                     self.PutItemOnShelf(itemid)
+                else:
+                    bLoaded = False
+            else:
+                bLoaded = False
+        return bLoaded
 
     def UpdateShelfMenuUI(self, evt):
         """Enable/Disable shelf items based on whether they support
