@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 67034 2011-02-26 18:30:53Z CJP $"
-__revision__ = "$Revision: 67034 $"
+__svnid__ = "$Id: ed_stc.py 67115 2011-03-03 04:28:25Z CJP $"
+__revision__ = "$Revision: 67115 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -34,6 +34,7 @@ from profiler import Profile_Get as _PGET
 from syntax import syntax
 import util
 import ed_basestc
+import ed_marker
 import ed_msg
 import ed_mdlg
 import ed_txt
@@ -957,10 +958,9 @@ class EditraStc(ed_basestc.EditraBaseStc):
         elif margin_num == ed_basestc.MARK_MARGIN:
             # Bookmarks ect...
             line_clicked = self.LineFromPosition(evt.GetPosition())
-            marker = self.MarkerGet(line_clicked)
-            if marker & (1<<ed_basestc.MARKER_BOOKMARK):
+            if ed_marker.Bookmark().IsSet(self, line_clicked):
                 self.RemoveBookmark(line_clicked)
-            elif marker & (1<<ed_basestc.MARKER_BREAKPOINT):
+            elif ed_marker.Breakpoint.AnySet(self, line_clicked):
                 # TODO: callback for plugins that set breakpoint?
                 self.DeleteBreakpoint(line_clicked)
             else:
