@@ -20,8 +20,8 @@ U{http://editra.org/?page=docs&doc=ess_spec}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 66518 2011-01-02 04:36:30Z CJP $"
-__revision__ = "$Revision: 66518 $"
+__svnid__ = "$Id: ed_style.py 66957 2011-02-18 22:20:00Z CJP $"
+__revision__ = "$Revision: 66957 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -36,8 +36,8 @@ from profiler import Profile_Get, Profile_Set
 import eclib
 
 # Globals
-STY_ATTRIBUTES     = u"face fore back size modifiers"
-STY_EX_ATTRIBUTES  = u"eol bold italic underline"
+STY_ATTRIBUTES     = (u"face", u"fore", u"back", u"size", u"modifiers")
+STY_EX_ATTRIBUTES  = (u"eol", u"bold", u"italic", u"underline")
 
 # Parser Values
 RE_ESS_COMMENT = re.compile("\/\*[^*]*\*+([^/][^*]*\*+)*\/")
@@ -47,13 +47,7 @@ RE_HEX_STR = re.compile("#[0-9a-fA-F]{3,6}")
 #--------------------------------------------------------------------------#
 
 class StyleItem(object):
-    """A storage class for holding styling information
-    @todo: The extra Attributes should be saved as a separate attribute in the
-           StyleItem. This currently causes problems when customizing values in
-           the StyleEditor. Changing this is fairly easy in this class but it
-           will require changes to the StyleMgr and Editor as well.
-
-    """
+    """A storage class for holding styling information """
     __slots__ = ('null', 'fore', 'face', 'back', 'size', '_exattr')
     def __init__(self, fore=u"", back=u"", face=u"", size=u"", ex=None):
         """Initializes the Style Object.
@@ -90,20 +84,29 @@ class StyleItem(object):
         self.size = size     # Font point size
         self._exattr = ex    # Extra attributes
 
-    def __eq__(self, si2):
+    def __eq__(self, other):
         """Defines the == operator for the StyleItem Class
         @param si2: style item to compare to
         @return: whether the two items are equal
         @rtype: bool
 
         """
-        return str(self) == str(si2)
+        return unicode(self) == unicode(other)
+
+    def __ne__(self, other):
+        """Defines != operator for the StyleItem Class"""
+        return unicode(self) != unicode(other)
 
     def __str__(self):
-        """Converts StyleItem to a string
+        """Convert StyleItem to string"""
+        uni = unicode(self)
+        return uni.encode('utf-8')
+
+    def __unicode__(self):
+        """Converts StyleItem to Unicode
         @note: This return string is in a format that can be accepted by
                Scintilla. No spaces may be in the string after the ':'.
-        @return: string representation of the StyleItem
+        @return: Unicode representation of the StyleItem
 
         """
         style_str = list()
@@ -114,8 +117,8 @@ class StyleItem(object):
         if self.face:
             style_str.append(u"face:%s" % self.face)
         if self.size:
-            style_str.append(u"size:%s" % str(self.size))
-        if len(self._exattr): 
+            style_str.append(u"size:%s" % unicode(self.size))
+        if len(self._exattr):
             style_str.append(u"modifiers:" +  u','.join(self._exattr))
 
         style_str = u",".join(style_str)
@@ -180,7 +183,7 @@ class StyleItem(object):
         @return: string
 
         """
-        return ",".join(self.GetModifierList())
+        return u",".join(self.GetModifierList())
 
     def GetModifierList(self):
         """Get the list of modifiers
@@ -210,7 +213,7 @@ class StyleItem(object):
         @return: bool
 
         """
-        return len(self.__str__())
+        return len(unicode(self))
 
     def Nullify(self):
         """Clear all values and set item as Null
@@ -219,7 +222,7 @@ class StyleItem(object):
         """
         self.null = True
         for attr in ('fore', 'face', 'back', 'size'):
-            setattr(self, attr, '')
+            setattr(self, attr, u'')
         self._exattr = list()
 
     #---- Set Functions ----#
@@ -238,7 +241,7 @@ class StyleItem(object):
             attrib = atom.split(u':')
             if len(attrib) == 2 and attrib[0] in STY_ATTRIBUTES:
                 last_set = attrib[0]
-                if last_set == "modifiers":
+                if last_set == u"modifiers":
                     self.SetExAttr(attrib[1])
                 else:
                     setattr(self, attrib[0], attrib[1])
@@ -298,7 +301,7 @@ class StyleItem(object):
         self.null = False
         if size is None:
             size = u''
-        self.size = str(size)
+        self.size = unicode(size)
         if ex and ex not in self._exattr:
             self._exattr.append(ex)
 
@@ -394,7 +397,7 @@ class StyleMgr(object):
                 sty_dict[key] = NullStyleItem()
             else:
                 sty_dict[key] = StyleItem("#000000", "#FFFFFF",
-                                          "%(primary)s", "%(size)d")#, ex=list())
+                                          "%(primary)s", "%(size)d")
         return sty_dict
 
     def FindTagById(self, style_id):
@@ -857,6 +860,7 @@ class StyleMgr(object):
 
         """
         if not isinstance(value, StyleItem):
+            self.LOG("[ed_style][warn] Bad data in SetStyleTag(%s)" % repr(value))
             return False
 
         StyleMgr.STYLES[self.style_set][style_tag] = value
@@ -890,7 +894,8 @@ class StyleMgr(object):
             defaultd = DEF_STYLE_DICT
             dstyle = style_dict.get('default_style', None)
             if dstyle is None:
-                style_dict['default_style'] = defaultd['default_style']
+                self.LOG("[ed_style][warn] default_style is undefined")
+                style_dict['default_style'] = defaultd['default_style'].Clone()
 
             # Set any undefined styles to match the default_style
             for tag, item in defaultd.iteritems():
@@ -898,7 +903,7 @@ class StyleMgr(object):
                     if tag in ('select_style',):
                         style_dict[tag] = NullStyleItem()
                     else:
-                        style_dict[tag] = style_dict['default_style']
+                        style_dict[tag] = style_dict['default_style'].Clone()
 
             StyleMgr.STYLES[name] = self.PackStyleSet(style_dict)
             return True
@@ -918,6 +923,7 @@ class StyleMgr(object):
         lexer = self.GetLexer()
         for syn in synlst:
             if len(syn) != 2:
+                self.LOG("[ed_style][warn] Bogus Syntax Spec %s" % repr(syn))
                 continue
             else:
                 self.StyleSetSpec(syn[0], self.GetStyleByName(syn[1]))
@@ -1081,7 +1087,7 @@ def MergeFonts(style_dict, font_dict):
 
     """
     for style in style_dict:
-        st_str = str(style_dict[style])
+        st_str = unicode(style_dict[style])
         if u'%' in st_str:
             style_dict[style].SetAttrFromStr(st_str % font_dict)
     return style_dict
