@@ -12,8 +12,8 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 65714 2010-10-01 19:15:39Z CJP $"
-__revision__ = "$Revision: 65714 $"
+__svnid__ = "$Id: ed_txt.py 66746 2011-01-24 20:55:53Z CJP $"
+__revision__ = "$Revision: 66746 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -284,8 +284,12 @@ class EdFile(ebmlib.FileObjectImpl):
             try:
                 stxt = txt.encode(enc)
                 self.encoding = enc
+            except LookupError, msg:
+                Log("[ed_txt][err] Invalid encoding: %s" % enc)
+                Log("[ed_txt][err] %s" % msg)
+                self.SetLastError(unicde(msg))
             except UnicodeEncodeError, msg:
-                Log("[ed_txt][err] Failed to encode text with %s" % self.encoding)
+                Log("[ed_txt][err] Failed to encode text with %s" % enc)
                 Log("[ed_txt][err] %s" % msg)
                 self.SetLastError(unicode(msg))
             else:
@@ -516,7 +520,7 @@ class FileReadThread(threading.Thread):
         @param task: generator method to call
 
         """
-        threading.Thread.__init__(self)
+        super(FileReadThread, self).__init__()
 
         # Attributes
         self.cancel = False
@@ -557,7 +561,7 @@ class FileLoadEvent(wx.PyEvent):
     """Event to signal that a chunk of text haes been read"""
     def __init__(self, etype, eid, value=None, state=FL_STATE_READING):
         """Creates the event object"""
-        wx.PyEvent.__init__(self, eid, etype)
+        super(FileLoadEvent, self).__init__(eid, etype)
 
         # Attributes
         self._state = state
