@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 65708 2010-10-01 13:06:40Z CJP $"
-__revision__ = "$Revision: 65708 $"
+__svnid__ = "$Id: util.py 66833 2011-02-02 21:53:44Z CJP $"
+__revision__ = "$Revision: 66833 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -437,16 +437,27 @@ def GetFileManagerCmd():
         else:
             return 'nautilus'
 
+def GetUserConfigBase():
+    """Get the base user configuration directory path"""
+    cbase = ed_glob.CONFIG['CONFIG_BASE']
+    if cbase is None:
+        cbase = wx.StandardPaths_Get().GetUserDataDir()
+        if wx.Platform == '__WXGTK__':
+            if u'.config' not in cbase and not os.path.exists(cbase):
+                # If no existing configuration return xdg config path
+                base, cfgdir = os.path.split(cbase)
+                tmp_path = os.path.join(base, '.config')
+                if os.path.exists(tmp_path):
+                    cbase = os.path.join(tmp_path, cfgdir.lstrip(u'.'))
+    return cbase + os.sep
+
 def HasConfigDir(loc=u""):
     """ Checks if the user has a config directory and returns True
     if the config directory exists or False if it does not.
     @return: whether config dir in question exists on an expected path
 
     """
-    cbase = ed_glob.CONFIG['CONFIG_BASE']
-    if cbase is None:
-        cbase = wx.StandardPaths_Get().GetUserDataDir() + os.sep
-
+    cbase = GetUserConfigBase()
     to_check = os.path.join(cbase, loc)
     return os.path.exists(to_check)
 
@@ -455,12 +466,9 @@ def MakeConfigDir(name):
     @param name: name of config directory to make in user config dir
 
     """
-    cbase = ed_glob.CONFIG['CONFIG_BASE']
-    if cbase is None:
-        cbase = wx.StandardPaths_Get().GetUserDataDir()
-
+    cbase = GetUserConfigBase()
     try:
-        os.mkdir(cbase + os.sep + name)
+        os.mkdir(cbase + name)
     except (OSError, IOError):
         pass
 
@@ -485,10 +493,7 @@ def CreateConfigDir():
 
     """
     #---- Resolve Paths ----#
-    config_dir = ed_glob.CONFIG['CONFIG_BASE']
-    if config_dir is None:
-        config_dir = wx.StandardPaths_Get().GetUserDataDir() + os.sep
-
+    config_dir = GetUserConfigBase()
     profile_dir = os.path.join(config_dir, u"profiles")
     dest_file = os.path.join(profile_dir, u"default.ppb")
     ext_cfg = [u"cache", u"styles", u"plugins"]
@@ -523,14 +528,9 @@ def ResolvConfigDir(config_dir, sys_only=False):
            the code has proven itself.
 
     """
-    stdpath = wx.StandardPaths_Get()
-
     # Try to get a User config directory
     if not sys_only:
-        user_config = ed_glob.CONFIG['CONFIG_BASE']
-        if user_config is None:
-            user_config = stdpath.GetUserDataDir() + os.sep
-
+        user_config = GetUserConfigBase()
         user_config = os.path.join(user_config, config_dir)
 
         if os.path.exists(user_config):
@@ -570,25 +570,25 @@ def ResolvConfigDir(config_dir, sys_only=False):
     # Tokenize path
     pieces = path.split(os.sep)
 
-    if os.sys.platform == 'win32':
+    if wx.Platform == u'__WXMSW__':
         # On Windows the exe is in same dir as config directories
         pro_path = os.sep.join(pieces[:-1])
 
         if os.path.isabs(pro_path):
             pass
-        elif pro_path == "":
+        elif pro_path == u"":
             pro_path = os.getcwd()
             pieces = pro_path.split(os.sep)
             pro_path = os.sep.join(pieces[:-1])
         else:
             pro_path = os.path.abspath(pro_path)
-    elif os.sys.platform == "darwin":
+    elif wx.Platform == u'__WXMAC__':
         # On OS X the config directories are in the applet under Resources
+        stdpath = wx.StandardPaths_Get()
         pro_path = stdpath.GetResourcesDir()
         pro_path = os.path.join(pro_path, config_dir)
     else:
         pro_path = os.sep.join(pieces[:-2])
-
         if pro_path.startswith(os.sep):
             pass
         elif pro_path == u"":
@@ -599,7 +599,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
         else:
             pro_path = os.path.abspath(pro_path)
 
-    if os.sys.platform != "darwin":
+    if wx.Platform != u'__WXMAC__':
         pro_path = pro_path + os.sep + config_dir + os.sep
 
     path = os.path.normpath(pro_path) + os.sep
